M4_quarterly_data: Quarterly time series data from the M4 Competition

M4_quarterly_dataR Documentation

Quarterly time series data from the M4 Competition

Description

The data set contains 30 selected time series on a quarterly basis from the M4 Competition.

Usage

data(M4_quarterly_data)

Format

A time series object of class tibble with 2818 rows and 4 columns:

  • index: Date and time index

  • series: Time series ID from M4 forecasting competition

  • category: Category from M4 forecasting competition

  • value: Measurement variable

M4 Competition

Examples

data(M4_quarterly_data)

tscv documentation built on May 13, 2026, 9:07 a.m.