mae_vec: Calculate the mean absolute error

View source: R/metrics.R

mae_vecR Documentation

Calculate the mean absolute error

Description

Calculate the mean absolute error of a numeric vector.

Usage

mae_vec(truth, estimate, na_rm = TRUE)

Arguments

truth

Numeric vector containing the actual values.

estimate

Numeric vector containing the forecasts.

na_rm

Logical value. If TRUE, missing values are removed.

Details

mae_vec() computes the average absolute forecast error abs(truth - estimate). The metric is reported in the same units as the original data.

Value

A numeric value.

See Also

Other accuracy functions: make_accuracy(), make_errors(), mape_vec(), me_vec(), mpe_vec(), mse_vec(), rmse_vec(), smape_vec()

Examples

truth <- c(10, 20, 30)
estimate <- c(8, 22, 25)

mae_vec(truth, estimate)

truth_na <- c(10, 20, NA)
estimate_na <- c(8, 22, 25)
mae_vec(truth_na, estimate_na)

tscv documentation built on May 13, 2026, 9:07 a.m.