View source: R/methods-fable.R
| DSHW | R Documentation |
Specify a Double Seasonal Holt-Winters model for use with
fabletools::model().
DSHW(formula, ...)
formula |
A model formula specifying the response variable, for example
|
... |
Further arguments passed to |
DSHW() is a model specification wrapper around
forecast::dshw() for the fable, tsibble, and
fabletools ecosystem.
The model is useful for time series with two important seasonal patterns, such as hourly data with daily and weekly seasonality.
The seasonal periods must be supplied through the periods argument.
A model definition that can be used inside fabletools::model().
Other DSHW:
fitted.DSHW(),
forecast.DSHW(),
model_sum.DSHW(),
residuals.DSHW()
library(dplyr)
library(tsibble)
library(fabletools)
train_frame <- elec_load |>
filter(bidding_zone == "DE") |>
slice_head(n = 24 * 28) |>
as_tsibble(index = time)
model_frame <- train_frame |>
model("DSHW" = DSHW(value, periods = c(24, 168)))
model_frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.