Specify a median benchmark model for use with fabletools::model().
Arguments
- formula
A model formula specifying the response and optional
window()special, for examplevalue ~ window().- ...
Further arguments.
Value
A model definition that can be used inside fabletools::model().
Details
MEDIAN() forecasts future values using the median of the observed
response. The window() special controls whether the median is estimated
using all observations, a fixed trailing window, or a rolling window.
See also
Other MEDIAN:
fitted.MEDIAN(),
forecast.MEDIAN(),
model_sum.MEDIAN(),
residuals.MEDIAN()