Specify a seasonal mean benchmark model for use with
fabletools::model().
Arguments
- formula
A model formula specifying the response and
lag()special, for examplevalue ~ lag("year").- ...
Further arguments.
Value
A model definition that can be used inside fabletools::model().
Details
SMEAN() forecasts each future observation using the historical mean of
the matching seasonal position. Use the lag() special to define the
seasonal period, for example lag("year") for monthly data.
See also
Other SMEAN:
fitted.SMEAN(),
forecast.SMEAN(),
model_sum.SMEAN(),
residuals.SMEAN()