View source: R/methods-fable.R
| TBATS | R Documentation |
Specify a TBATS model for use with fabletools::model().
TBATS(formula, ...)
formula |
A model formula specifying the response variable, for example
|
... |
Further arguments passed to |
TBATS() is a model specification wrapper around
forecast::tbats() for the fable, tsibble, and
fabletools ecosystem.
TBATS stands for trigonometric seasonality, Box-Cox transformation, ARMA errors, trend, and seasonal components. It can be useful for time series with multiple or complex seasonal patterns.
The seasonal periods must be supplied through the periods argument.
A model definition that can be used inside fabletools::model().
Other TBATS:
fitted.TBATS(),
forecast.TBATS(),
model_sum.TBATS(),
residuals.TBATS()
library(dplyr)
library(tsibble)
library(fabletools)
train_frame <- elec_price |>
filter(bidding_zone == "DE") |>
slice_head(n = 24 * 21) |>
as_tsibble(index = time)
model_frame <- train_frame |>
model("TBATS" = TBATS(value, periods = c(24, 168)))
model_frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.