| estimate_acf | R Documentation |
Estimate the sample autocorrelation function for one or more time series in a
tibble.
estimate_acf(.data, context, lag_max = 24, level = 0.9, ...)
.data |
A |
context |
A named |
lag_max |
Integer. Maximum lag for which the autocorrelation is estimated. |
level |
Numeric value. Confidence level used to calculate the approximate significance bound. |
... |
Further arguments passed to |
estimate_acf() groups the input data by the series identifier supplied
in context and estimates the sample autocorrelation function for each
time series separately.
The output contains one row per series and lag. The column bound
contains an approximate significance threshold based on the selected
confidence level. The logical column sign indicates whether the
absolute autocorrelation is larger than this threshold.
A tibble with the series identifier and the columns type,
lag, value, bound, and sign.
Other data analysis:
acf_vec(),
estimate_kurtosis(),
estimate_mode(),
estimate_pacf(),
estimate_skewness(),
pacf_vec(),
summarise_data(),
summarise_split(),
summarise_stats()
library(dplyr)
context <- list(
series_id = "series",
value_id = "value",
index_id = "index"
)
data <- M4_monthly_data |>
filter(series %in% c("M23100", "M14395"))
estimate_acf(
.data = data,
context = context,
lag_max = 12
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.