Estimate the mode of a numeric distribution using kernel density estimation.
Arguments
- x
Numeric vector.
- na_rm
Logical value. If
TRUE, missing values are removed before estimation.- ...
Further arguments passed to
stats::density().
Details
The function computes a kernel density estimate with stats::density()
and returns the value of x at which the estimated density is largest.
Missing values are removed by default. Additional arguments are passed to
stats::density(), for example bw, kernel, or n.
See also
Other data analysis:
acf_vec(),
estimate_acf(),
estimate_kurtosis(),
estimate_pacf(),
estimate_skewness(),
pacf_vec(),
summarise_data(),
summarise_split(),
summarise_stats()