Estimate the skewness of a numeric distribution.
Details
The function computes the moment-based skewness
$$ \frac{\frac{1}{n}\sum_i (x_i - \bar{x})^3} {\left(\frac{1}{n}\sum_i (x_i - \bar{x})^2\right)^{3/2}} $$
Missing values are removed by default. Positive values indicate a distribution with a longer or heavier right tail; negative values indicate a distribution with a longer or heavier left tail.
See also
Other data analysis:
acf_vec(),
estimate_acf(),
estimate_kurtosis(),
estimate_mode(),
estimate_pacf(),
pacf_vec(),
summarise_data(),
summarise_split(),
summarise_stats()