| estimate_skewness | R Documentation |
Estimate the skewness of a numeric distribution.
estimate_skewness(x, na_rm = TRUE)
x |
Numeric vector. |
na_rm |
Logical value. If |
The function computes the moment-based skewness
\frac{\frac{1}{n}\sum_i (x_i - \bar{x})^3}
{\left(\frac{1}{n}\sum_i (x_i - \bar{x})^2\right)^{3/2}}
Missing values are removed by default. Positive values indicate a distribution with a longer or heavier right tail; negative values indicate a distribution with a longer or heavier left tail.
A numeric value giving the estimated skewness.
Other data analysis:
acf_vec(),
estimate_acf(),
estimate_kurtosis(),
estimate_mode(),
estimate_pacf(),
pacf_vec(),
summarise_data(),
summarise_split(),
summarise_stats()
x <- c(1, 2, 3, 4, 10, NA)
estimate_skewness(x)
estimate_skewness(x, na_rm = TRUE)
set.seed(123)
y <- rexp(100)
estimate_skewness(y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.