Calculate the mean absolute error of a numeric vector.
Details
mae_vec() computes the average absolute forecast error
abs(truth - estimate). The metric is reported in the same units as the
original data.
See also
Other accuracy functions:
make_accuracy(),
make_errors(),
mape_vec(),
me_vec(),
mpe_vec(),
mse_vec(),
rmse_vec(),
smape_vec()