| mae_vec | R Documentation |
Calculate the mean absolute error of a numeric vector.
mae_vec(truth, estimate, na_rm = TRUE)
truth |
Numeric vector containing the actual values. |
estimate |
Numeric vector containing the forecasts. |
na_rm |
Logical value. If |
mae_vec() computes the average absolute forecast error
abs(truth - estimate). The metric is reported in the same units as the
original data.
A numeric value.
Other accuracy functions:
make_accuracy(),
make_errors(),
mape_vec(),
me_vec(),
mpe_vec(),
mse_vec(),
rmse_vec(),
smape_vec()
truth <- c(10, 20, 30)
estimate <- c(8, 22, 25)
mae_vec(truth, estimate)
truth_na <- c(10, 20, NA)
estimate_na <- c(8, 22, 25)
mae_vec(truth_na, estimate_na)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.