Calculate the mean absolute percentage error of a numeric vector.
Details
mape_vec() computes the average absolute percentage forecast error:
abs((truth - estimate) / truth) * 100.
This metric is undefined when truth is zero and may return
Inf or NaN in such cases.
See also
Other accuracy functions:
mae_vec(),
make_accuracy(),
make_errors(),
me_vec(),
mpe_vec(),
mse_vec(),
rmse_vec(),
smape_vec()