mape_vec: Calculate the mean absolute percentage error

View source: R/metrics.R

mape_vecR Documentation

Calculate the mean absolute percentage error

Description

Calculate the mean absolute percentage error of a numeric vector.

Usage

mape_vec(truth, estimate, na_rm = TRUE)

Arguments

truth

Numeric vector containing the actual values.

estimate

Numeric vector containing the forecasts.

na_rm

Logical value. If TRUE, missing values are removed.

Details

mape_vec() computes the average absolute percentage forecast error: abs((truth - estimate) / truth) * 100.

This metric is undefined when truth is zero and may return Inf or NaN in such cases.

Value

A numeric value.

See Also

Other accuracy functions: mae_vec(), make_accuracy(), make_errors(), me_vec(), mpe_vec(), mse_vec(), rmse_vec(), smape_vec()

Examples

truth <- c(10, 20, 40)
estimate <- c(8, 22, 30)

mape_vec(truth, estimate)

truth_na <- c(10, 20, NA)
estimate_na <- c(8, 22, 25)
mape_vec(truth_na, estimate_na)

tscv documentation built on May 13, 2026, 9:07 a.m.