me_vec: Calculate the mean error

View source: R/metrics.R

me_vecR Documentation

Calculate the mean error

Description

Calculate the mean error of a numeric vector.

Usage

me_vec(truth, estimate, na_rm = TRUE)

Arguments

truth

Numeric vector containing the actual values.

estimate

Numeric vector containing the forecasts.

na_rm

Logical value. If TRUE, missing values are removed.

Details

me_vec() computes the average signed forecast error truth - estimate. Positive values indicate that forecasts are, on average, below the observed values. Negative values indicate that forecasts are, on average, above the observed values.

The metric is reported in the same units as the original data.

Value

A numeric value.

See Also

Other accuracy functions: mae_vec(), make_accuracy(), make_errors(), mape_vec(), mpe_vec(), mse_vec(), rmse_vec(), smape_vec()

Examples

truth <- c(10, 20, 30)
estimate <- c(8, 22, 25)

me_vec(truth, estimate)

truth_na <- c(10, 20, NA)
estimate_na <- c(8, 22, 25)
me_vec(truth_na, estimate_na)

tscv documentation built on May 13, 2026, 9:07 a.m.