Calculate the mean percentage error of a numeric vector.
Details
mpe_vec() computes the average signed percentage forecast error:
((truth - estimate) / truth) * 100. Positive values indicate that
forecasts are, on average, below the observed values in percentage terms.
Negative values indicate that forecasts are, on average, above the observed
values.
This metric is undefined when truth is zero and may return
Inf, -Inf, or NaN in such cases.
See also
Other accuracy functions:
mae_vec(),
make_accuracy(),
make_errors(),
mape_vec(),
me_vec(),
mse_vec(),
rmse_vec(),
smape_vec()