| mpe_vec | R Documentation |
Calculate the mean percentage error of a numeric vector.
mpe_vec(truth, estimate, na_rm = TRUE)
truth |
Numeric vector containing the actual values. |
estimate |
Numeric vector containing the forecasts. |
na_rm |
Logical value. If |
mpe_vec() computes the average signed percentage forecast error:
((truth - estimate) / truth) * 100. Positive values indicate that
forecasts are, on average, below the observed values in percentage terms.
Negative values indicate that forecasts are, on average, above the observed
values.
This metric is undefined when truth is zero and may return
Inf, -Inf, or NaN in such cases.
A numeric value.
Other accuracy functions:
mae_vec(),
make_accuracy(),
make_errors(),
mape_vec(),
me_vec(),
mse_vec(),
rmse_vec(),
smape_vec()
truth <- c(10, 20, 40)
estimate <- c(8, 22, 30)
mpe_vec(truth, estimate)
truth_na <- c(10, 20, NA)
estimate_na <- c(8, 22, 25)
mpe_vec(truth_na, estimate_na)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.