Calculate the mean squared error of a numeric vector.
Details
mse_vec() computes the average squared forecast error
(truth - estimate)^2. The metric is reported in squared units of the
original data.
See also
Other accuracy functions:
mae_vec(),
make_accuracy(),
make_errors(),
mape_vec(),
me_vec(),
mpe_vec(),
rmse_vec(),
smape_vec()