Estimate the sample partial autocorrelation function of a numeric vector.
Arguments
- x
Numeric vector.
- lag_max
Integer. Maximum lag for which the partial autocorrelation is estimated.
- ...
Further arguments passed to
stats::pacf().
Details
pacf_vec() is a small wrapper around stats::pacf(). It returns
the sample partial autocorrelations as a numeric vector for lags
1 to lag_max.
See also
Other data analysis:
acf_vec(),
estimate_acf(),
estimate_kurtosis(),
estimate_mode(),
estimate_pacf(),
estimate_skewness(),
summarise_data(),
summarise_split(),
summarise_stats()