| pacf_vec | R Documentation |
Estimate the sample partial autocorrelation function of a numeric vector.
pacf_vec(x, lag_max = 24, ...)
x |
Numeric vector. |
lag_max |
Integer. Maximum lag for which the partial autocorrelation is estimated. |
... |
Further arguments passed to |
pacf_vec() is a small wrapper around stats::pacf(). It returns
the sample partial autocorrelations as a numeric vector for lags
1 to lag_max.
A numeric vector containing the sample partial autocorrelations for lags
1 to lag_max.
Other data analysis:
acf_vec(),
estimate_acf(),
estimate_kurtosis(),
estimate_mode(),
estimate_pacf(),
estimate_skewness(),
summarise_data(),
summarise_split(),
summarise_stats()
library(dplyr)
x <- M4_monthly_data |>
filter(series == first(series)) |>
pull(value)
pacf_vec(
x = x,
lag_max = 12
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.