Calculate the root mean squared error of a numeric vector.
Details
rmse_vec() computes the square root of the mean squared forecast error.
The metric is reported in the same units as the original data.
See also
Other accuracy functions:
mae_vec(),
make_accuracy(),
make_errors(),
mape_vec(),
me_vec(),
mpe_vec(),
mse_vec(),
smape_vec()