rmse_vec: Calculate the root mean squared error

View source: R/metrics.R

rmse_vecR Documentation

Calculate the root mean squared error

Description

Calculate the root mean squared error of a numeric vector.

Usage

rmse_vec(truth, estimate, na_rm = TRUE)

Arguments

truth

Numeric vector containing the actual values.

estimate

Numeric vector containing the forecasts.

na_rm

Logical value. If TRUE, missing values are removed.

Details

rmse_vec() computes the square root of the mean squared forecast error. The metric is reported in the same units as the original data.

Value

A numeric value.

See Also

Other accuracy functions: mae_vec(), make_accuracy(), make_errors(), mape_vec(), me_vec(), mpe_vec(), mse_vec(), smape_vec()

Examples

truth <- c(10, 20, 30)
estimate <- c(8, 22, 25)

rmse_vec(truth, estimate)

truth_na <- c(10, 20, NA)
estimate_na <- c(8, 22, 25)
rmse_vec(truth_na, estimate_na)

tscv documentation built on May 13, 2026, 9:07 a.m.