Calculate the symmetric mean absolute percentage error of a numeric vector.
Details
smape_vec() computes the symmetric mean absolute percentage error:
abs(estimate - truth) / ((abs(truth) + abs(estimate)) / 2) * 100.
This metric is undefined when both truth and estimate are zero
and may return NaN in such cases.
See also
Other accuracy functions:
mae_vec(),
make_accuracy(),
make_errors(),
mape_vec(),
me_vec(),
mpe_vec(),
mse_vec(),
rmse_vec()