| summarise_data | R Documentation |
Calculate basic data-quality summary statistics for one or more time series.
summarise_data(.data, context)
.data |
A |
context |
A named |
summarise_data() groups the input data by the series identifier
supplied in context and returns one row per time series.
The function reports:
start: first time index;
end: last time index;
n_obs: number of observations;
n_missing: number of missing values;
pct_missing: percentage of missing values;
n_zeros: number of zero values;
pct_zeros: percentage of zero values.
A tibble containing one row per time series and the calculated summary
statistics.
Other data analysis:
acf_vec(),
estimate_acf(),
estimate_kurtosis(),
estimate_mode(),
estimate_pacf(),
estimate_skewness(),
pacf_vec(),
summarise_split(),
summarise_stats()
library(dplyr)
context <- list(
series_id = "series",
value_id = "value",
index_id = "index"
)
data <- M4_monthly_data |>
filter(series %in% c("M23100", "M14395"))
summarise_data(
.data = data,
context = context
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.