| summarise_stats | R Documentation |
Calculate descriptive statistics for one or more time series.
summarise_stats(.data, context)
.data |
A |
context |
A named |
summarise_stats() groups the input data by the series identifier
supplied in context and returns one row per time series.
The function reports:
mean: arithmetic mean;
median: median;
mode: kernel-density based mode estimate;
sd: standard deviation;
p0: minimum;
p25: 25 percent quantile;
p75: 75 percent quantile;
p100: maximum;
skewness: moment-based skewness;
kurtosis: moment-based kurtosis.
Missing values are removed when calculating the statistics.
A tibble containing one row per time series and the calculated
descriptive statistics.
Other data analysis:
acf_vec(),
estimate_acf(),
estimate_kurtosis(),
estimate_mode(),
estimate_pacf(),
estimate_skewness(),
pacf_vec(),
summarise_data(),
summarise_split()
library(dplyr)
context <- list(
series_id = "series",
value_id = "value",
index_id = "index"
)
data <- M4_monthly_data |>
filter(series %in% c("M23100", "M14395"))
summarise_stats(
.data = data,
context = context
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.